/** ============================================================================
 *  @file   _notify.c
 *
 *  @path   $(DSPLINK)/gpp/src/api/PrOS/
 *
 *  @desc   Implemetation of NOTIFY.
 *
 *  @ver    1.65.01.06
 *  ============================================================================
 *  Copyright (C) 2002-2009, Texas Instruments Incorporated -
 *  http://www.ti.com/
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  
 *  *  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  
 *  *  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  
 *  *  Neither the name of Texas Instruments Incorporated nor the names of
 *     its contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *  
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 *  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 *  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 *  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 *  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 *  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  ============================================================================
 */


/*  ----------------------------------- DSP/BIOS Link                 */
#include <dsplink.h>
#include <procdefs.h>

/*  ----------------------------------- Trace & Debug                 */
#include <_trace.h>

/*  ----------------------------------- User API                      */
#include <notify.h>
#include <_notify.h>

/*  ----------------------------------- OSAL Header                   */
#include <drvdefs.h>
#include <drv_api.h>

/*  ----------------------------------- USER Api                      */
#include <notify.h>


#if defined (__cplusplus)
extern "C" {
#endif /* defined (__cplusplus) */


/** ============================================================================
 *  @name   COMPONENT_ID
 *
 *  @desc   Component ID of this module. That will be used by TRC macros.
 *  ============================================================================
 */
#define COMPONENT_ID        ID_API_NOTIFY

/** ============================================================================
 *  @name   SET_FAILURE_REASON
 *
 *  @desc   Sets failure reason.
 *  ============================================================================
 */
#if defined (DDSP_DEBUG)
#define SET_FAILURE_REASON  \
            TRC_3PRINT (TRC_LEVEL7, \
                        "\nFailure: Status:[0x%x] File:[0x%x] Line:[%d]\n", \
                        status, FID_C_API_NOTIFY, __LINE__)
#else
#define SET_FAILURE_REASON { }
#endif /* if defined (DDSP_DEBUG) */


/*  ----------------------------------------------------------------------------
 *  @name   NOTIFY_initializeCount
 *
 *  @desc   Variable for tracking initialization count of component.
 *  ----------------------------------------------------------------------------
 */
extern Uint32 NOTIFY_initializeCount ;


/** ============================================================================
 *  @func   _NOTIFY_init
 *
 *  @desc   This function initializes the NOTIFY component.
 *
 *  @modif  NOTIFY_initializeCount
 *  ============================================================================
 */
EXPORT_API
DSP_STATUS
_NOTIFY_init (IN ProcessorId dspId)
{
    DSP_STATUS status = DSP_SOK ;
    CMD_Args   args             ;

    TRC_1ENTER ("_NOTIFY_init", dspId) ;

    args.apiArgs.notifyInitializeArgs.dspId = dspId ;

    if (NOTIFY_initializeCount == 0) {
        status = DRV_INVOKE (DRV_handle, CMD_NOTIFY_INITIALIZE, &args) ;
        if (DSP_FAILED (status)) {
            SET_FAILURE_REASON ;
        }
        else {
            NOTIFY_initializeCount = 1 ;
        }
    }
    else {
        NOTIFY_initializeCount++ ;
    }

    TRC_1LEAVE ("_NOTIFY_init", status) ;

    return status ;
}


/** ============================================================================
 *  @func   _NOTIFY_exit
 *
 *  @desc   This function Finalizes the NOTIFY component.
 *
 *  @modif  NOTIFY_initializeCount
 *  ============================================================================
 */
EXPORT_API
DSP_STATUS
_NOTIFY_exit (IN ProcessorId dspId)
{
    DSP_STATUS status = DSP_SOK ;
    CMD_Args   args             ;

    TRC_1ENTER ("_NOTIFY_exit", dspId) ;

    DBC_Require (NOTIFY_initializeCount > 0) ;
    DBC_Require (IS_VALID_PROCID (dspId)) ;

    if (NOTIFY_initializeCount == 1) {
        args.apiArgs.notifyFinalizeArgs.dspId = dspId ;

        status = DRV_INVOKE (DRV_handle, CMD_NOTIFY_FINALIZE, &args) ;
        if (DSP_FAILED (status)) {
            SET_FAILURE_REASON ;
        }
    }
    else if (NOTIFY_initializeCount > 0) {
        NOTIFY_initializeCount-- ;
    }
    else {
    }

    TRC_1LEAVE ("_NOTIFY_exit", status) ;

    return status ;
}


#if defined (__cplusplus)
}
#endif /* defined (__cplusplus) */
