/** ============================================================================
 *  @file   omap3530_phy_shmem.c
 *
 *  @path   $(DSPLINK)/gpp/src/arch/OMAP3530/shmem/WinCE/
 *
 *  @desc   WinCE shmem driver interface file.
 *
 *  @ver    1.65.01.06
 *  ============================================================================
 *  Copyright (C) 2002-2009, Texas Instruments Incorporated -
 *  http://www.ti.com/
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  
 *  *  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  
 *  *  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  
 *  *  Neither the name of Texas Instruments Incorporated nor the names of
 *     its contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *  
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 *  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 *  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 *  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 *  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 *  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  ============================================================================
 */


/*  ----------------------------------- OS Headers                  */
#include <windows.h>
#include <ceddk.h>

/*  ----------------------------------- DSP/BIOS Link               */
#include <dsplink.h>
#include <_dsplink.h>

/*  ----------------------------------- Trace & Debug               */
#include <_trace.h>
#include <trc.h>
#include <print.h>

/*  ----------------------------------- OSAL Headers                */
#include <osal.h>

/*  ----------------------------------- Hardware Abstraction Layer  */
#include <omap3530_hal.h>
#include <omap3530_hal_boot.h>
#include <omap3530_hal_intgen.h>
#include <omap3530_hal_pwr.h>
#include <omap3530_phy_shmem.h>
#include <omap3530_hal_mmu.h>


#if defined (__cplusplus)
extern "C" {
#endif


/** ============================================================================
 *  @macro  COMPONENT_ID
 *
 *  @desc   Component and Subcomponent Identifier.
 *  ============================================================================
 */
#define  COMPONENT_ID       ID_ARCH_SHMEM_PHY

/** ============================================================================
 *  @macro  SET_FAILURE_REASON
 *
 *  @desc   Sets failure reason.
 *  ============================================================================
 */
#if defined (DDSP_DEBUG)
#define SET_FAILURE_REASON TRC_SetReason (status,FID_C_ARCH_PHY_SHMEM,__LINE__)
#else
#define SET_FAILURE_REASON
#endif /* if defined (DDSP_DEBUG) */


/** ============================================================================
 *  @name   OMAP3530_shmemInterface
 *
 *  @desc   Interface functions exported by the Shared Driver subcomponent.
 *  ============================================================================
 */
HAL_Interface OMAP3530_shmemInterface = { &OMAP3530_phyShmemInit,
                                          &OMAP3530_phyShmemExit,
                                          &OMAP3530_halBootCtrl,
                                          &OMAP3530_halIntCtrl,
                                          &OMAP3530_halMmuCtrl,
                                          NULL,
                                          &OMAP3530_halPwrCtrl,
                                          NULL,
                                          NULL,
                                          NULL,
                                          NULL} ;


/* ============================================================================
 *  @func   OMAP3530_phyShmemInit
 *
 *  @desc   Initializes Shared/OMAP Gem device.
 *
 *  @modif  None.
 *  ============================================================================
 */


NORMAL_API
DSP_STATUS
OMAP3530_phyShmemInit (IN Pvoid halObj)
{
    DSP_STATUS        status    = DSP_SOK ;
    OMAP3530_HalObj * halObject = NULL    ;
    MemMapInfo  mapInfo ;
    

    TRC_1ENTER ("OMAP3530_phyShmemInit", halObj) ;

    DBC_Require (NULL != halObj) ;

    halObject = (OMAP3530_HalObj *) halObj ;

    /* GENERAL_CONTROL_BASE */
    mapInfo.src  = GENERAL_CONTROL_BASE - (GENERAL_CONTROL_BASE % PAGE_SIZE) ;
    mapInfo.size = GENERAL_CONTROL_MAP_SIZE ; // assuming page_size multiple 
    mapInfo.memAttrs = MEM_UNCACHED ;
    status = MEM_Map (&mapInfo) ;
    if (DSP_FAILED (status)) {
        SET_FAILURE_REASON ;
        halObject->generalCtrlBase = 0 ;
    }
    else {
        halObject->generalCtrlBase = mapInfo.dst + (GENERAL_CONTROL_BASE % PAGE_SIZE);
    }

    /* Clock Manager */
    mapInfo.src  = IVA2_CM_BASE - (IVA2_CM_BASE % PAGE_SIZE) ;
    mapInfo.size = CM_MAP_SIZE ; // assuming page_size multiple 
    mapInfo.memAttrs = MEM_UNCACHED ;
    status = MEM_Map (&mapInfo) ;
    if (DSP_FAILED (status)) {
        SET_FAILURE_REASON ;
        halObject->iva2CmBase = 0;
        halObject->coreCmBase = 0; 
        halObject->perCmBase  = 0;   
    }
    else {
        halObject->iva2CmBase = mapInfo.dst + (IVA2_CM_BASE % PAGE_SIZE);
        halObject->coreCmBase = halObject->iva2CmBase + (CORE_CM_BASE-IVA2_CM_BASE); 
        halObject->perCmBase  = halObject->iva2CmBase + (PER_CM_BASE-IVA2_CM_BASE); 
    }

    /* Power Reset Module */
    mapInfo.src  = IVA2_PRM_BASE - (IVA2_PRM_BASE % PAGE_SIZE) ;
    mapInfo.size = IVA2_PRM_MAP_SIZE ; // assuming page_size multiple 
    mapInfo.memAttrs = MEM_UNCACHED ;
    status = MEM_Map (&mapInfo) ;
    if (DSP_FAILED (status)) {
        SET_FAILURE_REASON ;
        halObject->iva2PrmBase = 0 ;
    }
    else {
        halObject->iva2PrmBase = mapInfo.dst + (IVA2_PRM_BASE % PAGE_SIZE);
    }

    /* Mailbox Module */
    mapInfo.src  = MAILBOX_BASE - (MAILBOX_BASE % PAGE_SIZE) ;
    mapInfo.size = IVA2_PRM_MAP_SIZE ; // assuming page_size multiple 
    mapInfo.memAttrs = MEM_UNCACHED ;
    status = MEM_Map (&mapInfo) ;
    if (DSP_FAILED (status)) {
        SET_FAILURE_REASON ;
        halObject->mailboxBase = 0 ;
    }
    else {
        halObject->mailboxBase = mapInfo.dst + (MAILBOX_BASE % PAGE_SIZE);
    }
    
    /* MMU */
    mapInfo.src  = MMU_BASE - (MMU_BASE % PAGE_SIZE);
    mapInfo.size = MMU_SIZE ;// assuming page_size multiple 
    mapInfo.memAttrs = MEM_UNCACHED ;
    status = MEM_Map (&mapInfo) ;
    if (DSP_FAILED (status)) {
        SET_FAILURE_REASON ;
        halObject->mmuBase = 0 ;
    }
    else {
        halObject->mmuBase = mapInfo.dst + (MMU_BASE % PAGE_SIZE);
    }

    TRC_1LEAVE ("OMAP3530_phyShmemInit", status) ;

    return status ;
}


/* ============================================================================
 *  @func   OMAP3530_phyShmemExit
 *
 *  @desc   Finalizes Shared/OMAP Gem device.
 *
 *  @modif  None.
 *  ============================================================================
 */
NORMAL_API
DSP_STATUS
OMAP3530_phyShmemExit (IN Pvoid halObj)
{
    DSP_STATUS     status = DSP_SOK ;
    OMAP3530_HalObj * halObject = (OMAP3530_HalObj *) halObj ;
    MemUnmapInfo      unmapInfo                              ;

    TRC_1ENTER ("OMAP3530_phyShmemExit", halObj) ;

    DBC_Require (NULL != halObject) ;

    unmapInfo.addr = halObject->generalCtrlBase - (halObject->generalCtrlBase % PAGE_SIZE);
    unmapInfo.size = GENERAL_CONTROL_MAP_SIZE;
    if (unmapInfo.addr != 0) {
        MEM_Unmap (&unmapInfo) ;
        if (DSP_FAILED (status)) {
            SET_FAILURE_REASON ;
        }
        halObject->generalCtrlBase = 0 ;
    }

    unmapInfo.addr = halObject->iva2CmBase - (halObject->iva2CmBase % PAGE_SIZE);
    unmapInfo.size = CM_MAP_SIZE;
    if (unmapInfo.addr != 0) {
        MEM_Unmap (&unmapInfo) ;
        if (DSP_FAILED (status)) {
            SET_FAILURE_REASON ;
        }
        halObject->iva2CmBase= 0 ;
    }

    
    unmapInfo.addr = halObject->iva2PrmBase - (halObject->iva2PrmBase % PAGE_SIZE);
    unmapInfo.size = IVA2_PRM_MAP_SIZE;
    if (unmapInfo.addr != 0) {
        MEM_Unmap (&unmapInfo) ;
        if (DSP_FAILED (status)) {
            SET_FAILURE_REASON ;
        }
        halObject->iva2PrmBase= 0 ;
    }

    unmapInfo.addr = halObject->mailboxBase - (halObject->mailboxBase % PAGE_SIZE);
    unmapInfo.size = MAILBOX_MAP_SIZE;
    if (unmapInfo.addr != 0) {
        MEM_Unmap (&unmapInfo) ;
        if (DSP_FAILED (status)) {
            SET_FAILURE_REASON ;
        }
        halObject->mailboxBase= 0 ;
    }

    unmapInfo.addr = halObject->mmuBase - (halObject->mmuBase % PAGE_SIZE);
    unmapInfo.size = MMU_SIZE ;
    if (unmapInfo.addr != 0) {
        MEM_Unmap (&unmapInfo) ;
        if (DSP_FAILED (status)) {
            SET_FAILURE_REASON ;
        }
        halObject->mmuBase = 0 ;
    }

    TRC_1LEAVE ("OMAP3530_phyShmemExit", status) ;

    return status ;
}


#if defined (__cplusplus)

}
#endif
