/** ============================================================================
 *  @file   linklog.c
 *
 *  @path   $(DSPLINK)/gpp/src/gen/
 *
 *  @desc   This file implements the functions of LOG subcomponent.
 *
 *  @ver    1.65.01.06
 *  ============================================================================
 *  Copyright (C) 2002-2009, Texas Instruments Incorporated -
 *  http://www.ti.com/
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  
 *  *  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  
 *  *  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  
 *  *  Neither the name of Texas Instruments Incorporated nor the names of
 *     its contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *  
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 *  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 *  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 *  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 *  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 *  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  ============================================================================
 */


/*  ----------------------------------- DSP/BIOS Link                 */
#include <dsplink.h>
#if defined (MSGQ_COMPONENT)
#include <msgqdefs.h>
#endif /* if defined (MSGQ_COMPONENT) */

/*  ----------------------------------- Trace & Debug               */
#include <_trace.h>
#include <trc.h>
#include <print.h>

/*  ----------------------------------- Generated LOG CFG header      */
#if defined (LOG_COMPONENT)
#include <log.h>
#include <linklog.h>
#endif /* if defined (LOG_COMPONENT) */

#if defined (__cplusplus)
extern "C" {
#endif

#if defined (LOG_COMPONENT)
/** ============================================================================
 *  @name   TRACE_OBJECT
 *
 *  @desc   External reference to trace object defined by application.
 *  ============================================================================
 */
extern LOG_Handle TRACE_OBJECT ;


/** ============================================================================
 *  @func   DSPLINKLOG_LogEvent
 *
 *  @desc   Logs a event
 *
 *  @modif  None
 *  ============================================================================
 */
EXPORT_API
Void
DSPLINKLOG_LogEvent (IN DsplinkLogEventType eventType,
                     IN Uint32 id,
                     IN Uint32 queId,
                     IN Uint32 addr,
                     IN Uint32 size,
                     IN Uint32 arg1,
                     IN Uint32 arg2)
{
    Uint32 argQueId ;
    Uint32 argAddr  ;

    TRC_5ENTER ("DSPLINKLOG_LogEvent",
                eventType,
                id,
                queId,
                addr,
                size) ;

    /* TBD comment for time being
     * DBC_Require (TRACE_OBJECT != NULL) ;
     */

    /*
     * Format for logging (in bits)
     * |<- que ID (32) ->|<- Address (32) ->|<- event (16) ->|<- size (16) ->|
     */
    if (!(   ((id >= ID_START) && (id <= ID_END))
#if defined (MSGQ_COMPONENT)
         || ((id >= MSGQ_INTERNALIDSSTART) && (id <= MSGQ_INTERNALIDSEND))
         || ((id >= MSGQ_MQTMSGIDSSTART)   && (id <= MSGQ_MQTMSGIDSEND))
#endif /* if defined (MSGQ_COMPONENT) */
         )) {
        argQueId      = (Uint32) queId ;
        argAddr       = (Uint32) addr ;

        (Void) arg1 ;
        (Void) arg2 ;

        LOG_event (TRACE_OBJECT,
                   argQueId,
                   argAddr,
                   (Uint32) eventType,
                   (Uint32) id,
                   (Uint32) size) ;
    }

    TRC_0LEAVE ("DSPLINKLOG_LogEvent") ;
}
#endif /* if defined (LOG_COMPONENT) */


#if defined (__cplusplus)
}
#endif /* extern "C" */
