/** ============================================================================
 *  @file   scale_os.c
 *
 *  @path   $(DSPLINK)/gpp/src/samples/scale/WinCE/
 *
 *  @desc   OS specific implementation of functions used by the scale
 *          sample application.
 *
 *  @ver    1.65.01.06
 *  ============================================================================
 *  Copyright (C) 2002-2009, Texas Instruments Incorporated -
 *  http://www.ti.com/
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  
 *  *  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  
 *  *  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  
 *  *  Neither the name of Texas Instruments Incorporated nor the names of
 *     its contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *  
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 *  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 *  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 *  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 *  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 *  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  ============================================================================
 */


/*  ----------------------------------- OS Specific Headers           */
#include <windows.h>

/*  ----------------------------------- DSP/BIOS Link                 */
#include <dsplink.h>

/*  ----------------------------------- Application Header            */
#include <scale.h>


#if defined (__cplusplus)
extern "C" {
#endif /* defined (__cplusplus) */

/** ============================================================================
 *  @name   MAXSTRLENGTH
 *
 *  @desc   Maximum Length of the Trace String.
 *  ============================================================================
 */
#define MAXSTRLENGTH        256


/** ============================================================================
 *  @func   SCALE_0Print
 *
 *  @desc   Print a message without any arguments.
 *
 *  @modif  None
 *  ============================================================================
 */
NORMAL_API
Void
SCALE_0Print (Char8 * str)
{
    TCHAR  buffer[MAXSTRLENGTH];    
    mbstowcs (buffer, (const char *)str, MAXSTRLENGTH);
    RETAILMSG(1, (TEXT("%s"), buffer));
}


/** ============================================================================
 *  @func   SCALE_1Print
 *
 *  @desc   Print a message with one arguments.
 *
 *  @modif  None
 *  ============================================================================
 */
NORMAL_API
Void
SCALE_1Print (Char8 * str, Uint32 arg)
{
    TCHAR  buffer[MAXSTRLENGTH];
    TCHAR  fmtSpec[MAXSTRLENGTH];
    
    mbstowcs (fmtSpec, (const char *)str, MAXSTRLENGTH);
    wsprintf (buffer, fmtSpec, arg);
    RETAILMSG(1, (TEXT("%s"), buffer));    
}


/** ============================================================================
 *  @func   SCALE_Sleep
 *
 *  @desc   Sleeps for the specified number of microseconds.
 *
 *  @modif  None
 *  ============================================================================
 */
NORMAL_API
Void
SCALE_Sleep (Uint32 uSec)
{
    Sleep ((uSec + 999)/1000) ;    
}


#if defined (__cplusplus)
}
#endif /* defined (__cplusplus) */
