#   ============================================================================
#   @file   link.mk
#
#   @path   $(DSPLINK)/make/PrOS/DRX45X/
#
#   @desc   This makefile contains rules to link sources.
#
#   @ver    1.65.01.06
#   ============================================================================
#   Copyright (C) 2002-2009, Texas Instruments Incorporated -
#   http://www.ti.com/
#
#   Redistribution and use in source and binary forms, with or without
#   modification, are permitted provided that the following conditions
#   are met:
#   
#   *  Redistributions of source code must retain the above copyright
#      notice, this list of conditions and the following disclaimer.
#   
#   *  Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#   
#   *  Neither the name of Texas Instruments Incorporated nor the names of
#      its contributors may be used to endorse or promote products derived
#      from this software without specific prior written permission.
#   
#   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
#   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
#   THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
#   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#   OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#   WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#   OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
#   EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#   ============================================================================


ifndef LINK_MK

define LINK_MK
endef


include $(MAKEROOT)$(DIRSEP)$(BUILDOS)$(DIRSEP)systools.mk
include $(MAKEROOT)$(DIRSEP)gendefs.mk
include $(MAKEROOT)$(DIRSEP)$(BUILDOS)$(DIRSEP)osdefs.mk
include $(MAKEROOT)$(DIRSEP)rulebase.mk

include $(BUILDOS)$(DIRSEP)$(COMP_DETAILS)


#   ============================================================================
#   Clear environment variables
#   ============================================================================

INCLUDE     :=
LIB         :=
C_OPTION    :=
C_DIR       :=
A_DIR       :=


#   ============================================================================
#   Search path for standard libraries
#   ============================================================================
STD_LIB_PATH    := $(addprefix $(LD_SW_LIB) , $(OSLIB_GENERIC))
STD_LIB_PATH    += $(addprefix $(LD_SW_LIB) , $(OSLIB_PLATFORM))

ifneq ("$(OSLIB_VARIANT)", "")
STD_LIB_PATH    += $(addprefix $(LD_SW_LIB) , $(OSLIB_VARIANT))
endif


#   ============================================================================
#   Rules to build targets
#   ============================================================================

target_deb  := $(addsuffix .deb, $(COMP_TARGET))
target_rel  := $(addsuffix .rel, $(COMP_TARGET))


#   ============================================================================
#   @rule   trgdeb
#
#   @desc   Builds the target for DEBUG variant.
#   ============================================================================

ifeq ("$(COMP_TYPE)", "LIB")
trgdeb  : libdeb
endif


#   ============================================================================
#   @rule   trgrel
#
#   @desc   Builds the target for RELEASE variant.
#   ============================================================================

ifeq ("$(COMP_TYPE)", "LIB")
trgrel  : librel
endif


#   ############################################################################
#   BUILD AN ARCHIVE
#   ############################################################################


ifeq ("$(COMP_TYPE)", "LIB")

#   ----------------------------------------------------------------------------
#   Command line arguments for archiver
#   ----------------------------------------------------------------------------

ARCHIVE_DEB   = $(COMP_BINARY_DEB)$(DIRSEP)$(basename $(@))
ARCHIVE_REL   = $(COMP_BINARY_REL)$(DIRSEP)$(basename $(@))

#   ----------------------------------------------------------------------------
#   Append suitable path to each user defined library
#   ----------------------------------------------------------------------------

ifeq ("$(USR_LIBS)", "")

USR_LIBS_DEB  :=
USR_LIBS_REL  :=

DEPENDS_DEB   :=
DEPENDS_REL   :=

ARGS_ARCH_DEB := $(COMP_OBJECT_DEB)
ARGS_ARCH_REL := $(COMP_OBJECT_REL)

depend_deb    :=
depend_rel    :=

else

DEPENDS_DEB   := $(COMP_OBJECT_DEB)$(DIRSEP)DEPEND
DEPENDS_REL   := $(COMP_OBJECT_REL)$(DIRSEP)DEPEND

USR_LIBS_DEB  := $(addprefix $(BUILD_EXPORT_DEB)$(DIRSEP), $(USR_LIBS))
USR_LIBS_REL  := $(addprefix $(BUILD_EXPORT_REL)$(DIRSEP), $(USR_LIBS))

ARGS_ARCH_DEB := $(COMP_OBJECT_DEB)     $(DEPENDS_DEB)
ARGS_ARCH_REL := $(COMP_OBJECT_REL)     $(DEPENDS_REL)

depend_deb    := $(addsuffix .dep, $(USR_LIBS_DEB))
depend_rel    := $(addsuffix .dep, $(USR_LIBS_REL))

endif


#   ----------------------------------------------------------------------------
#   @rule   libdeb
#
#   @desc   Builds the target library for DEBUG variant.
#   ----------------------------------------------------------------------------

.PHONY: depend_dirdeb $(depend_deb)

depend_dirdeb :
	$(CMDECHO)$(RUNIF) "exist $(DEPENDS_DEB)" "$(DELETE) $(DEPENDS_DEB)$(DIRSEP)*.*" "" >$(TRASH)
	$(CMDECHO)$(IFF) exist $(DEPENDS_DEB) $(RMDIR) $(DEPENDS_DEB)
	$(CMDECHO)$(RUNIF) "exist $(DEPENDS_DEB)" "" "$(CMDECHO)$(MKDIR) $(DEPENDS_DEB)"


$(depend_deb): depend_dirdeb
	$(CMDECHO)$(IFF) exist $(basename $@)                                   \
	$(CMDECHO)$(DISPLAY) Exploding $(basename $@)...                    &&  \
	$(CMDECHO)$(CHDIR) $(DEPENDS_DEB) && $(ARCHIVER) -x $(basename $@)


$(target_deb): $(depend_deb)
	$(CMDECHO)$(DISPLAY) Generating $(basename $@)...
	$(CMDECHO)$(DISPLAY) ARGS_ARCH_DEB $(ARGS_ARCH_DEB)...
	$(CMDECHO)$(RUNIF) "exist $(EXPORT_INC_PLATFORM_USR)" "" "$(MKDIR) $(EXPORT_INC_PLATFORM_USR)"
	$(CMDECHO)$(COPYFILES) "$(PROJ_INC_USR)" "$(EXPORT_INC_PLATFORM_USR)" > $(TRASH)
	$(CMDECHO)$(RUNIF) "exist $(EXPORT_INC_PLATFORM_SYS)" "" "$(MKDIR) $(EXPORT_INC_PLATFORM_SYS)"
	$(CMDECHO)$(RUNIF) "exist $(EXPORT_INC_PLATFORM_SYS_ARCH)" "" "$(MKDIR) $(EXPORT_INC_PLATFORM_SYS_ARCH)"
	$(CMDECHO)$(COPYFILES) "$(PROJ_INC_ARCH)" "$(EXPORT_INC_PLATFORM_SYS_ARCH)" > $(TRASH)
	$(foreach device, $(TI_DSPLINK_DSPDEVICES), $(CMDECHO)$(RUNIF) "exist $(EXPORT_INC_PLATFORM_SYS_ARCH)$(DIRSEP)$(device)" "" "$(MKDIR) $(EXPORT_INC_PLATFORM_SYS_ARCH)$(DIRSEP)$(device)")
	$(foreach device, $(TI_DSPLINK_DSPDEVICES), $(CMDECHO)$(COPYFILES) "$(PROJ_INC_ARCH)$(DIRSEP)$(device)" "$(EXPORT_INC_PLATFORM_SYS_ARCH)$(DIRSEP)$(device)" > $(TRASH))
	$(CMDECHO)$(ARCHIVER) $(STD_AR_FLAGS) $(ARCHIVE_DEB) $(foreach dir, $(ARGS_ARCH_DEB), $(dir)$(DIRSEP)*.obj)
	$(CMDECHO)$(COPY) $(ARCHIVE_DEB) $(BUILD_EXPORT_DEB)\.

libdeb  : $(target_deb)


#   ----------------------------------------------------------------------------
#   @rule   librel
#
#   @desc   Builds the target library for RELEASE variant.
#   ----------------------------------------------------------------------------
.PHONY: depend_dirrel $(depend_rel)

depend_dirrel :
	$(CMDECHO)$(RUNIF) "exist $(DEPENDS_REL)" "$(DELETE) $(DEPENDS_REL)$(DIRSEP)*.*" "" >$(TRASH)
	$(CMDECHO)$(IFF) exist $(DEPENDS_REL) $(RMDIR) $(DEPENDS_REL)
	$(CMDECHO)$(RUNIF) "exist $(DEPENDS_REL)" "" "$(CMDECHO)$(MKDIR) $(DEPENDS_REL)"



$(depend_rel): depend_dirrel
	$(CMDECHO)$(IFF) exist $(basename $@)                                  \
	$(CMDECHO)$(DISPLAY) Exploding $(basename $@)...                    && \
	$(CMDECHO)$(CHDIR) $(DEPENDS_REL) && $(ARCHIVER) -x $(basename $@)

$(target_rel): $(depend_rel)
	$(CMDECHO)$(DISPLAY) Generating $(basename $@)...
	$(CMDECHO)$(DISPLAY) ARGS_ARCH_REL $(ARGS_ARCH_REL)...
	$(CMDECHO)$(RUNIF) "exist $(EXPORT_INC_PLATFORM_USR)" "" "$(MKDIR) $(EXPORT_INC_PLATFORM_USR)"
	$(CMDECHO)$(COPYFILES) "$(PROJ_INC_USR)" "$(EXPORT_INC_PLATFORM_USR)" > $(TRASH)
	$(CMDECHO)$(RUNIF) "exist $(EXPORT_INC_PLATFORM_SYS)" "" "$(MKDIR) $(EXPORT_INC_PLATFORM_SYS)"
	$(CMDECHO)$(RUNIF) "exist $(EXPORT_INC_PLATFORM_SYS_ARCH)" "" "$(MKDIR) $(EXPORT_INC_PLATFORM_SYS_ARCH)"
	$(CMDECHO)$(COPYFILES) "$(PROJ_INC_ARCH)" "$(EXPORT_INC_PLATFORM_SYS_ARCH)" > $(TRASH)
	$(foreach device, $(TI_DSPLINK_DSPDEVICES), $(CMDECHO)$(RUNIF) "exist $(EXPORT_INC_PLATFORM_SYS_ARCH)$(DIRSEP)$(device)" "" "$(MKDIR) $(EXPORT_INC_PLATFORM_SYS_ARCH)$(DIRSEP)$(device)")
	$(foreach device, $(TI_DSPLINK_DSPDEVICES), $(CMDECHO)$(COPYFILES) "$(PROJ_INC_ARCH)$(DIRSEP)$(device)" "$(EXPORT_INC_PLATFORM_SYS_ARCH)$(DIRSEP)$(device)" > $(TRASH))
	$(CMDECHO)$(ARCHIVER) $(STD_AR_FLAGS) $(ARCHIVE_REL) $(foreach dir, $(ARGS_ARCH_REL), $(dir)$(DIRSEP)*.obj)
	$(CMDECHO)$(COPY) $(ARCHIVE_REL) $(BUILD_EXPORT_REL)\.

librel  : $(target_rel)


endif   # ifeq ("$(COMP_TYPE)", "LIB")


endif   # ifndef LINK_MK
